PeerSpec

Struct PeerSpec 

pub struct PeerSpec {
    pub host: String,
    pub port: u16,
    pub dc: String,
    pub rack: String,
    pub tokens: Vec<u32>,
    pub is_secure: bool,
}
Description of a peer to add to the cluster.

This is the inverse of PeerSnapshot: a snapshot describes a peer that already exists, a PeerSpec describes one that the admin caller wants to join.

Fields

host: String

Hostname or numeric IP.

port: u16

TCP port.

dc: String

Datacenter name.

rack: String

Rack name.

tokens: Vec<u32>

Token list as u32s.

is_secure: bool

True when the peer expects an encrypted dnode link.