pub enum HintStoreOpenError {
Dir {
path: PathBuf,
source: Error,
},
Segment {
path: PathBuf,
source: Error,
},
}Expand description
Errors produced by HintStore::open.
Variants
Dir
The segment directory could not be created or read.
Segment
A segment file could not be read during replay.