ConnRoleTag

Enum ConnRoleTag 

#[non_exhaustive]
pub enum ConnRoleTag { Proxy, Client, Server, DnodeProxy, DnodeClient, DnodeServer, }
Summary tag for the role of a connection at accept time.

Mirrors crate::io::reactor::ConnRole but renamed to keep the embed surface independent of the I/O substrate.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Proxy

Listener that accepted a client connection.



Client

Connected client.



Server

Outbound datastore connection.



DnodeProxy

Listener that accepted a peer connection.



DnodeClient

Inbound peer connection.



DnodeServer

Outbound peer connection.