MsgFlags

Struct MsgFlags 

pub struct MsgFlags {
Show 13 fields pub is_error: bool, pub is_ferror: bool, pub quit: bool, pub expect_datastore_reply: bool, pub done: bool, pub fdone: bool, pub swallow: bool, pub dnode_header_prepended: bool, pub rsp_sent: bool, pub is_read: bool, pub needs_repair: bool, pub rewrite_with_ts_possible: bool, pub rspmgrs_inited: bool,
}
Bag of boolean lifecycle flags used by the request and response pipelines.

Fields

is_error: bool

Message is currently in the error state.

is_ferror: bool

At least one fragment of this multi-message vector errored.

quit: bool

Caller issued a quit request.

expect_datastore_reply: bool

Caller expects the datastore to produce a reply.

done: bool

Reply has been routed to the caller.

fdone: bool

Every fragment of this vector finished.

swallow: bool

Discard the corresponding response on arrival.

dnode_header_prepended: bool

A DNODE header has already been prepended to the mbuf chain.

rsp_sent: bool

Response for this request has been written to the wire.

is_read: bool

Read request (vs write).

needs_repair: bool

Marked by the dispatcher that a repair must be issued.

rewrite_with_ts_possible: bool

Request body can be safely rewritten with a timestamp.

rspmgrs_inited: bool

Response managers have been initialised.