pub struct ConnHandle(/* private fields */);Expand description
Stable, process-unique connection identifier.
Connections are identified by a monotonic 64-bit counter so the id stays unique across reconnects and across transports (TCP, QUIC).
Implementations
Sourceimpl ConnHandle
impl ConnHandle
Sourcepub fn raw(self) -> u64
pub fn raw(self) -> u64
Borrow the raw 64-bit id.
Examples
let listener = tokio::net::TcpListener::bind("127.0.0.1:0").await.unwrap();
let addr = listener.local_addr().unwrap();
let _accept = tokio::spawn(async move {
let (s, _) = listener.accept().await.unwrap();
drop(s);
});
let s = tokio::net::TcpStream::connect(addr).await.unwrap();
let transport = Box::new(TcpTransport::new(s, ConnRole::Server));
let conn = Conn::new(transport, ConnRole::Server);
assert!(conn.handle().raw() > 0);Trait Implementations
Sourceimpl Clone for ConnHandle
impl Clone for ConnHandle
Sourcefn clone(&self) -> ConnHandle
fn clone(&self) -> ConnHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConnHandle
impl Debug for ConnHandle
Sourceimpl Hash for ConnHandle
impl Hash for ConnHandle
Sourceimpl PartialEq for ConnHandle
impl PartialEq for ConnHandle
Sourcefn eq(&self, other: &ConnHandle) -> bool
fn eq(&self, other: &ConnHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ConnHandle
impl Eq for ConnHandle
impl StructuralPartialEq for ConnHandle