#[non_exhaustive]pub enum FragmentError {
EmptyKeys,
UnsupportedType,
}Expand description
Errors produced by memcache_fragment.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyKeys
Caller invoked the fragmenter on a retrieval request with no parsed keys.
UnsupportedType
Caller invoked the fragmenter on an unsupported message type.