pub struct HashTag {
pub open: u8,
pub close: u8,
}Expand description
Optional hash-tag delimiters. When set the parser carves out the inner range as the routing tag on every parsed key.
Fields
open: u8Opening byte of the hash tag.
close: u8Closing byte of the hash tag.