PoolField

Enum PoolField 

#[repr(usize)]
pub enum PoolField {
Show 45 variants ClientEof = 0, ClientErr = 1, ClientConnections = 2, ClientReadRequests = 3, ClientWriteRequests = 4, ClientDroppedRequests = 5, ClientNonQuorumWResponses = 6, ClientNonQuorumRResponses = 7, ServerEjects = 8, DnodeClientEof = 9, DnodeClientErr = 10, DnodeClientConnections = 11, DnodeClientInQueue = 12, DnodeClientInQueueBytes = 13, DnodeClientOutQueue = 14, DnodeClientOutQueueBytes = 15, PeerDroppedRequests = 16, PeerTimedoutRequests = 17, RemotePeerDroppedRequests = 18, RemotePeerTimedoutRequests = 19, RemotePeerFailoverRequests = 20, PeerEof = 21, PeerErr = 22, PeerTimedout = 23, RemotePeerTimedout = 24, PeerConnections = 25, PeerForwardError = 26, PeerRequests = 27, PeerRequestBytes = 28, PeerResponses = 29, PeerResponseBytes = 30, PeerEjectedAt = 31, PeerEjects = 32, PeerInQueue = 33, RemotePeerInQueue = 34, PeerInQueueBytes = 35, RemotePeerInQueueBytes = 36, PeerOutQueue = 37, RemotePeerOutQueue = 38, PeerOutQueueBytes = 39, RemotePeerOutQueueBytes = 40, PeerMismatchRequests = 41, ForwardError = 42, Fragments = 43, StatsCount = 44,
}
Typed handle for a pool metric.

Each variant is a typed handle for a metric; its as usize value is also the index into the metric vector held by PoolStats / ServerStats.

Variants



ClientEof = 0

eof on client connections



ClientErr = 1

errors on client connections



ClientConnections = 2

active client connections



ClientReadRequests = 3

client read requests



ClientWriteRequests = 4

client write responses



ClientDroppedRequests = 5

client dropped requests



ClientNonQuorumWResponses = 6

client non quorum write responses



ClientNonQuorumRResponses = 7

client non quorum read responses



ServerEjects = 8

times backend server was ejected



DnodeClientEof = 9

eof on dnode client connections



DnodeClientErr = 10

errors on dnode client connections



DnodeClientConnections = 11

active dnode client connections



DnodeClientInQueue = 12

dnode client requests in incoming queue



DnodeClientInQueueBytes = 13

current dnode client request bytes in incoming queue



DnodeClientOutQueue = 14

dnode client requests in outgoing queue



DnodeClientOutQueueBytes = 15

current dnode client request bytes in outgoing queue



PeerDroppedRequests = 16

local dc peer dropped requests



PeerTimedoutRequests = 17

local dc peer timedout requests



RemotePeerDroppedRequests = 18

remote dc peer dropped requests



RemotePeerTimedoutRequests = 19

remote dc peer timedout requests



RemotePeerFailoverRequests = 20

remote dc peer failover requests



PeerEof = 21

eof on peer connections



PeerErr = 22

errors on peer connections



PeerTimedout = 23

timeouts on local dc peer connections



RemotePeerTimedout = 24

timeouts on remote dc peer connections



PeerConnections = 25

active peer connections



PeerForwardError = 26

times we encountered a peer forwarding error



PeerRequests = 27

peer requests



PeerRequestBytes = 28

total peer request bytes



PeerResponses = 29

peer respones



PeerResponseBytes = 30

total peer response bytes



PeerEjectedAt = 31

timestamp when peer was ejected



PeerEjects = 32

times a peer was ejected



PeerInQueue = 33

local dc peer requests in incoming queue



RemotePeerInQueue = 34

remote dc peer requests in incoming queue



PeerInQueueBytes = 35

current peer request bytes in incoming queue



RemotePeerInQueueBytes = 36

current peer request bytes in incoming queue to remote DC



PeerOutQueue = 37

local dc peer requests in outgoing queue



RemotePeerOutQueue = 38

remote dc peer requests in outgoing queue



PeerOutQueueBytes = 39

current peer request bytes in outgoing queue



RemotePeerOutQueueBytes = 40

current peer request bytes in outgoing queue to remote DC



PeerMismatchRequests = 41

current dnode peer mismatched messages



ForwardError = 42

times we encountered a forwarding error



Fragments = 43

fragments created from a multi-vector request



StatsCount = 44

stats request

Implementations

Source

impl PoolField

pub const ALL: &'static [PoolField]

All variants of this metric set, in canonical order.

Examples
use dynomite::stats::PoolField;
assert!(!PoolField::ALL.is_empty());
pub fn name(self) -> &'static str

Lower-case identifier as it appears in the JSON output.

Examples
use dynomite::stats::PoolField;
let name = PoolField::ALL[0].name();
assert!(!name.is_empty());
pub fn kind(self) -> StatsMetricType

Whether this metric is a counter, gauge, or timestamp.

Examples
use dynomite::stats::{PoolField, StatsMetricType};
let k = PoolField::ALL[0].kind();
assert!(matches!(k, StatsMetricType::Counter | StatsMetricType::Gauge | StatsMetricType::Timestamp));
pub fn description(self) -> &'static str

Human-readable description used by --describe-stats.

Examples
use dynomite::stats::PoolField;
let d = PoolField::ALL[0].description();
assert!(!d.is_empty());
pub fn index(self) -> usize

Index of this metric in the corresponding stats vector.

Examples
use dynomite::stats::PoolField;
assert_eq!(PoolField::ALL[0].index(), 0);