OrderedMap

Struct OrderedMap 

pub struct OrderedMap<K: Ord, V> { /* private fields */ }
Ordered key/value map backed by BTreeMap.

Examples

use dynomite::util::rbtree::OrderedMap;

let mut t: OrderedMap<u64, &'static str> = OrderedMap::new();
t.insert(10, "ten");
t.insert(30, "thirty");
t.insert(20, "twenty");
assert_eq!(t.lower_bound(&15), Some((&20, &"twenty")));
assert_eq!(t.min(), Some((&10, &"ten")));

Implementations

Source

impl<K: Ord, V> OrderedMap<K, V>

pub fn new() -> Self

Construct an empty map.

Examples
use dynomite::util::rbtree::OrderedMap;
let m: OrderedMap<u32, u32> = OrderedMap::new();
assert!(m.is_empty());
pub fn insert(&mut self, key: K, value: V) -> Option<V>

Insert value at key, returning the previous value (if any).

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
assert_eq!(m.insert(1, 10), None);
assert_eq!(m.insert(1, 20), Some(10));
pub fn remove(&mut self, key: &K) -> Option<V>

Remove the entry at key.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(1, 10);
assert_eq!(m.remove(&1), Some(10));
pub fn get(&self, key: &K) -> Option<&V>

Look up the value at key.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(1, 10);
assert_eq!(m.get(&1), Some(&10));
pub fn len(&self) -> usize

Number of entries.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(1, 1);
assert_eq!(m.len(), 1);
pub fn is_empty(&self) -> bool

Whether the map is empty.

Examples
use dynomite::util::rbtree::OrderedMap;
let m: OrderedMap<u32, u32> = OrderedMap::new();
assert!(m.is_empty());
pub fn clear(&mut self)

Drop every entry.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(1, 1);
m.clear();
assert!(m.is_empty());
pub fn min(&self) -> Option<(&K, &V)>

Smallest entry, or None if the map is empty.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(3, 30);
m.insert(1, 10);
assert_eq!(m.min(), Some((&1, &10)));
pub fn max(&self) -> Option<(&K, &V)>

Largest entry, or None if the map is empty.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(3, 30);
m.insert(1, 10);
assert_eq!(m.max(), Some((&3, &30)));
pub fn lower_bound(&self, probe: &K) -> Option<(&K, &V)>

Smallest entry whose key is >= probe. Used by the token ring for “find the owner of this key” queries.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut t: OrderedMap<u64, &str> = OrderedMap::new();
t.insert(10, "a");
t.insert(20, "b");
assert_eq!(t.lower_bound(&15), Some((&20, &"b")));
assert_eq!(t.lower_bound(&25), None);
assert_eq!(t.lower_bound(&20), Some((&20, &"b")));
pub fn iter(&self) -> impl Iterator<Item = (&K, &V)>

In-order iterator over the entries.

Examples
use dynomite::util::rbtree::OrderedMap;
let mut m: OrderedMap<u32, u32> = OrderedMap::new();
m.insert(2, 0);
m.insert(1, 0);
let keys: Vec<u32> = m.iter().map(|(k, _)| *k).collect();
assert_eq!(keys, vec![1, 2]);