pub struct KeyPos { /* private fields */ }Expand description
Position record for one parsed key.
The full key bytes live in key. When a hash tag is configured
and the tag delimiters are present in the key, tag indexes the
range inside key that should be hashed for routing; otherwise
tag covers the whole key and is equal to 0..key.len().
Examples
use dynomite::msg::keypos::KeyPos;
let kp = KeyPos::without_tag(b"user:42".to_vec());
assert_eq!(kp.key(), b"user:42");
assert_eq!(kp.tag_bytes(), b"user:42");Implementations