pub struct MsgFlags {Show 13 fields
pub is_error: bool,
pub is_ferror: bool,
pub quit: bool,
pub expect_datastore_reply: bool,
pub done: bool,
pub fdone: bool,
pub swallow: bool,
pub dnode_header_prepended: bool,
pub rsp_sent: bool,
pub is_read: bool,
pub needs_repair: bool,
pub rewrite_with_ts_possible: bool,
pub rspmgrs_inited: bool,
}Expand description
Bag of boolean lifecycle flags used by the request and response pipelines.
Fields
is_error: boolMessage is currently in the error state.
is_ferror: boolAt least one fragment of this multi-message vector errored.
quit: boolCaller issued a quit request.
expect_datastore_reply: boolCaller expects the datastore to produce a reply.
done: boolReply has been routed to the caller.
fdone: boolEvery fragment of this vector finished.
swallow: boolDiscard the corresponding response on arrival.
dnode_header_prepended: boolA DNODE header has already been prepended to the mbuf chain.
rsp_sent: boolResponse for this request has been written to the wire.
is_read: boolRead request (vs write).
needs_repair: boolMarked by the dispatcher that a repair must be issued.
rewrite_with_ts_possible: boolRequest body can be safely rewritten with a timestamp.
rspmgrs_inited: boolResponse managers have been initialised.