pub struct DnodeServerConn { /* private fields */ }Expand description
Outbound DNODE peer connection driver.
Implementations
Sourceimpl DnodeServerConn
impl DnodeServerConn
Sourcepub fn new(conn: Conn, requests: Receiver<OutboundRequest>) -> Self
pub fn new(conn: Conn, requests: Receiver<OutboundRequest>) -> Self
Wrap an outbound peer connection.
Examples
use dynomite::io::reactor::{ConnRole, TcpTransport};
use dynomite::net::{Conn, DnodeServerConn};
use tokio::sync::mpsc;
let s = tokio::net::TcpStream::connect("127.0.0.1:0").await.unwrap();
let conn = Conn::new(Box::new(TcpTransport::new(s, ConnRole::DnodePeerServer)), ConnRole::DnodePeerServer);
let (_tx, rx) = mpsc::channel(8);
let _ = DnodeServerConn::new(conn, rx);Sourcepub async fn run_with(
&mut self,
requests: &mut Receiver<OutboundRequest>,
) -> Result<(), NetError>
pub async fn run_with( &mut self, requests: &mut Receiver<OutboundRequest>, ) -> Result<(), NetError>
Drive the FSM using a borrowed request receiver. Useful for reconnect supervisors that own the receiver across multiple connection attempts and pass it in by reference.
Errors
Forwarded transport / DNODE parse errors.