ConnHandle

Struct ConnHandle 

pub struct ConnHandle<C: Send + 'static> { /* private fields */ }
Handle returned by ConnPool::get.

Dropping the handle returns the connection to the pool. Call ConnHandle::discard when the connection is no longer healthy (the slot will then be re-filled by the next get).

Implementations

Source

impl<C: Send + 'static> ConnHandle<C>

pub fn get(&self) -> &C

Borrow the wrapped connection.

pub fn get_mut(&mut self) -> &mut C

Mutably borrow the wrapped connection.

pub fn release(self)

Return the connection to the pool. Equivalent to dropping the handle.

pub fn discard(self)

Discard the connection (do not return it to the pool).