pub enum DmsgDispatch {
Bypass,
Forward,
}Expand description
Outcome of dmsg_process.
Bypass means the header has been recognised as control traffic
and the cluster layer should not pass the message further down
the protocol stack.
Variants
Bypass
Frame consumed by a control-plane handler.
Forward
Frame should continue through the data-plane stack.