#[non_exhaustive]pub enum DnodeError {
OutOfSpace,
BadMagic,
BadNumber,
MissingCrlf,
BadType,
TruncatedData,
}Expand description
Errors that can be raised when encoding or parsing a DNODE header without going through the streaming state machine.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutOfSpace
Buffer too small to encode the header.
BadMagic
Header does not begin with the magic literal.
BadNumber
Numeric field could not be parsed.
MissingCrlf
Trailing CRLF missing.
BadType
Type discriminator out of range.
TruncatedData
Inline data shorter than the declared mlen.